package com.ozs.web.controller.base;

import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.core.page.TableDataInfo;
import com.ozs.common.utils.StringUtils;
import com.ozs.base.domain.BaseSupplier;
import com.ozs.base.service.BaseSupplierService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 供应商管理
 *
 * @author sunhh
 */
@Api(tags="供应商管理")
@RestController
@RequestMapping("/base/supplier")
public class BaseSupplierController extends BaseController {

    @Autowired
    private BaseSupplierService baseSupplierService;

    @ApiOperation(value = "新增供应商户", notes = "")
    @PostMapping("/insertBaseSupplier")
    public AjaxResult insertBaseSupplier(BaseSupplier baseSupplier) {
        if (StringUtils.isNull(baseSupplier) || StringUtils.isNull(baseSupplier.getSupplierName())) {
            return error("供应商名称不能为空");
        }
        return toAjax(baseSupplierService.insertBaseSupplier(baseSupplier));
    }

    @ApiOperation(value = "删除供应商户", notes = "必传ID")
    @PostMapping("/deleteBaseSupplier")
    public AjaxResult deleteBaseSupplier(BaseSupplier baseSupplier) {
        if (StringUtils.isNull(baseSupplier) || StringUtils.isNull(baseSupplier.getId())) {
            return error("删除ID不能为空");
        }
        return toAjax(baseSupplierService.deleteBaseSupplier(baseSupplier.getId()));
    }

    @ApiOperation(value = "修改供应商户", notes = "必传ID及修改字段")
    @PostMapping("/updateBaseSupplier")
    public AjaxResult updateBaseSupplier(BaseSupplier baseSupplier) {
        if (StringUtils.isNull(baseSupplier) || StringUtils.isNull(baseSupplier.getId())) {
            return error("修改数据及ID不能为空");
        }
        return toAjax(baseSupplierService.updateBaseSupplier(baseSupplier));
    }

    @ApiOperation(value = "预先采购开关", notes = "必传id,supplierAdvancePurchase 其他字段不传； 关闭传0，开启传1")
    @PostMapping("/updateBaseSupplierAdvancePurchase")
    public AjaxResult updateBaseSupplierAdvancePurchase(BaseSupplier baseSupplier) {
        if (StringUtils.isNull(baseSupplier) || StringUtils.isNull(baseSupplier.getId()) || StringUtils.isNotNull(baseSupplier.getSupplierAdvancePurchase())) {
            return error("预先采购及ID不能为空");
        }
        return toAjax(baseSupplierService.updateBaseSupplier(baseSupplier));
    }

    @ApiOperation(value = "黑白名单开关", notes = "必传id,supplierType 其他字段不传； 黑名单传0，白名单传1")
    @PostMapping("/updateSupplierType")
    public AjaxResult updateSupplierType(BaseSupplier baseSupplier) {
        if (StringUtils.isNull(baseSupplier) || StringUtils.isNull(baseSupplier.getId()) || StringUtils.isNotNull(baseSupplier.getSupplierType())) {
            return error("状态及ID不能为空");
        }
        return toAjax(baseSupplierService.updateBaseSupplier(baseSupplier));
    }

    @ApiOperation(value = "查询供应商户", notes = "非必传 查询条件：供应商名称，供应商类型，供应商状态，预先采购状态")
    @PostMapping("/selectBaseSupplier")
    public TableDataInfo selectBaseSupplier(BaseSupplier baseSupplier) {
        List<BaseSupplier> baseSupplierList = baseSupplierService.selectBaseSupplier(baseSupplier);
        return getDataTable(baseSupplierList);
    }
}
