package com.ozs.plan.service;


import com.ozs.common.core.domain.AjaxResult;
import com.ozs.plan.doman.PlanOfYears;
import com.ozs.plan.doman.vo.requestVo.PlanOfYearsStandardVo;
import com.ozs.plan.doman.vo.responseVo.PlanOfYearsResponseVo;

import java.util.List;

/**
 * 系统访问日志情况信息 服务层
 *
 * @author bu
 */
public interface PlanOfYearsService {

    /**
     * 查询年度计划记录集合
     *
     * @param vo 年度计划请求对象
     * @return 年度计划记录集合
     */
    public List<PlanOfYears> selectPlanOfYearsList(PlanOfYearsStandardVo vo);

    /**
     * 创建年度计划
     *
     * @param yearsStandardVo 年度计划请求对象
     */
    public AjaxResult insertPlanOfYears(PlanOfYearsStandardVo yearsStandardVo);

    /**
     * 批量删除年度计划
     *
     * @param planIds 需要删除的年度计划ID
     * @return 结果
     */
    public AjaxResult deletePlanOfYearsByIds(Long[] planIds);

    /**
     * 批量删除年度计划
     *
     * @param planYearId 需要删除的年度计划ID
     * @return 结果
     */
    public AjaxResult deletePlanOfYearsById(Long planYearId);

    /**
     * 根据id获取年度计划信息
     *
     * @param yearsStandardVo 年度计划请求对象
     * @return 结果
     */
    public AjaxResult view(PlanOfYearsStandardVo yearsStandardVo);

    /**
     * 修改年度计划
     *
     * @param yearsStandardVo 修改年度计划请求对象
     * @return 结果
     */
    public AjaxResult update(PlanOfYearsStandardVo yearsStandardVo);

    /**
     * 导入年度计划数据
     *
     * @return 结果
     */
    public String importPlanOfYears(List<PlanOfYears> planOfYears, boolean isUpdateSupport, String operName);

    /**
     * 提交年度计划
     *
     * @param yearsStandardVo 提交年度计划请求对象
     * @return 结果
     */
    public AjaxResult commit(PlanOfYearsStandardVo yearsStandardVo);

    /**
     * 审核年度计划
     *
     * @param yearsStandardVo 需要审核的年度计划
     * @return 结果
     */
    public AjaxResult reviewTo(PlanOfYearsStandardVo yearsStandardVo);

    /**
     * 审核年度计划退回
     *
     * @param yearsStandardVo 需要审核的年度计划
     * @return 结果
     */
    public AjaxResult reviewReturn(PlanOfYearsStandardVo yearsStandardVo);
}
